==> eiffelstudio-16.05.tar: F_code/C50/eb2450.c <==
/*
 * Code for class EB_COMMAND_MENU_ITEM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "eb2450.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EB_COMMAND_MENU_ITEM}.make */
void F3425_41553 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("make", 3424, Current, 1, 1, 42518);
	RTGC;
	RTHOOK(1);
	F2839_32827(Current);
	RTHOOK(2);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	F5158_69839(RTCW(tr1), Current);
	RTHOOK(4);
	loc1 = arg1;
	loc1 = RTRV(eif_new_type(3416, 0x00), loc1);
	RTHOOK(5);
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		RTHOOK(6);
		F3417_41412(RTCW(loc1), Current);
	}
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {EB_COMMAND_MENU_ITEM}.internal_recycle */
void F3425_41554 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("internal_recycle", 3424, Current, 0, 0, 42519);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	tr1 = F5158_69841(RTCW(tr1));
	tb1 = F2640_29132(RTCW(tr1), Current);
	if (tb1) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
		F5158_69840(RTCW(tr1), Current);
	}
	RTHOOK(3);
	*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) NULL;
	RTHOOK(4);
	F2679_29337(RTCV(F634_10937(Current)));
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EB_COMMAND_MENU_ITEM}.command */
EIF_REFERENCE F3425_41555 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_10_);
}


void EIF_Minit2450 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C50/eb2450.c <==
/*
 * Code for class EB_COMMAND_MENU_ITEM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "eb2450.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EB_COMMAND_MENU_ITEM}.make */
void F3429_37615 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("make", 3428, Current, 1, 1, 42903);
	RTGC;
	RTHOOK(1);
	F2774_29217(Current);
	RTHOOK(2);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	F5251_66051(RTCW(tr1), Current);
	RTHOOK(4);
	loc1 = arg1;
	loc1 = RTRV(eif_new_type(3419, 0x00),loc1);
	if (EIF_TEST(loc1)) {
		RTHOOK(5);
		F3420_37475(loc1, Current);
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EB_COMMAND_MENU_ITEM}.internal_recycle */
void F3429_37616 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("internal_recycle", 3428, Current, 0, 0, 42904);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	tr1 = F5251_66053(RTCW(tr1));
	tb1 = F2630_26819(RTCW(tr1), Current);
	if (tb1) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
		F5251_66052(RTCW(tr1), Current);
	}
	RTHOOK(3);
	*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) NULL;
	RTHOOK(4);
	F2669_26972(RTCV(F2865_30130(Current)));
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EB_COMMAND_MENU_ITEM}.command */
EIF_REFERENCE F3429_37617 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_10_);
}


void EIF_Minit2450 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
